package
Version:
v1.1.8
Opens a new window with list of versions in this module.
Published: Aug 5, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
app用来监听系统信号
回收资源
重启
...以后可扩充其他操作
Documentation
¶
Close 当不使用信号处理时,可直接调用Close回收资源
func RegistClose(f func())
RegistClose 注册回收资源
func RegistRestart(f func())
RegistRestart 注册重启资源
Source Files
¶
Click to show internal directories.
Click to hide internal directories.